@@ -3,10 +3,18 @@
 import curses
 from itertools import count
 from subprocess import Popen, PIPE
-from sys import platform
+from sys import platform, exit
+
+try:
+    import setproctitle
+except ImportError:
+    print
+    print "\033[91mError: You must install the setproctitle package.\033[0m"
+    print
+    exit()
 
 
-__version__ = "0.1.10"
+__version__ = "0.1.11"
 
 gunicorns = {} # gunicorn master process names/pids.
 selected_pid = None # Process ID of currently selected gunicorn master process.
@@ -175,12 +183,14 @@ def handle_keypress(screen):
         raise KeyboardInterrupt
 
 
-def format_row(pid="", port="", name="", mem="", workers=""):
+def format_row(pid="", port="", name="", mem="", workers="", prefix_char=" "):
     """
     Applies consistant padding to each of the columns in a row and serves as 
     the source of the overall screen width.
     """
-    row = " %-5s %-6s %-25s %8s %7s " % (pid, port, name, mem, workers)
+    row = "%s%-5s %-6s %-25s %8s %7s " \
+          % (prefix_char, pid, port, name, mem, workers)
+
     global screen_width
     if screen_width is None:
         screen_width = len(row)
@@ -203,7 +213,7 @@ def display_output(screen):
     blank_line = y = count(2).next
     win.addstr(y(), x, title.center(screen_width), curses.A_NORMAL)
     blank_line()
-    win.addstr(y(), x, format_row("PID", "PORT", "NAME", "MEM (MB)", "WORKERS"), 
+    win.addstr(y(), x, format_row(" PID", "PORT", "NAME", "MEM (MB)", "WORKERS"), 
         curses.A_STANDOUT)
     if not gunicorns:
         blank_line()
@@ -230,9 +240,12 @@ def display_output(screen):
                 workers = chars[workers]
             if pid == selected_pid:
                 attr = curses.A_STANDOUT
+                prefix_char = '> '
             else:
                 attr = curses.A_NORMAL
-            win.addstr(y(), x, format_row(pid, port, name, mem, workers), attr)
+                prefix_char = '  '
+            win.addstr(y(), x, format_row(pid, port, name, mem, workers,
+                                          prefix_char), attr)
     win.hline(y(), x, curses.ACS_HLINE, screen_width)
     blank_line()
     for line in instructions.split("\n"):
